==> viha-5.15.tar.gz: viha-5.15/kayttajat.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "kayttajat";
$file = basename(__FILE__);

include "common.php";
include "kayttaja-ok.php";

# tehdn valinta kaikista alueista tietylle kyttjlle.

function select_alue_ids($kayttajat_id) {
  $koko = ota_yksi("SELECT COUNT(*)
                    FROM alue
                    WHERE id > 2");
  if ($koko > 5)
    $koko = 5;
  echo "<select multiple size=\"$koko\" name=\"alue_ids[]\">\n";

  $sql =
    "SELECT id, alue
     FROM alue
     WHERE id > 2
     ORDER BY alue";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($data = mysql_fetch_row($result)) {
      $option_value = $data[0];
      $option_label = $data[1];
      echo "<option value=\"$option_value\"";
      if (ota_yksi("SELECT COUNT(*)
                    FROM kayttajat_alue
                    WHERE kayttajat_id = $kayttajat_id
                          AND alue_id = $option_value"))
	echo " selected";
      echo ">$option_label\n";
    }
  }
  
  echo "</select>\n";
}

# nytetn taulukossa olevat alueet

function list_alue_ids($alue_ids) {
  foreach ($alue_ids as $id) {
    echo " " . tab_col_id("alue","",$id);
  }
  echo "\n";
}

# tehdn alue_ids lista tietylle kyttjlle.
function fetch_alue_ids($id) {
  $ret = array();
  $sql = "SELECT alue_id FROM kayttajat_alue WHERE kayttajat_id = $id";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($d = mysql_fetch_row($result)) {
      $ret[] = $d[0];
    }
  }
  return $ret;
}

# asetetaan kyttjn alue_ids lista kantaan.
function set_alue_ids($now,$id,$alue_ids) {
  $now = date('Y-m-d H:i:s');
  $sql = "DELETE FROM kayttajat_alue WHERE kayttajat_id = $id;";
  my_mysql_query($sql);
  loki($sql);
  foreach ($alue_ids as $alue_id) {
    $sql =
      "INSERT INTO kayttajat_alue
       SET kayttajat_id = $id,
           alue_id = $alue_id,
           ts = '$now'";
      my_mysql_query($sql);
      loki($sql);
  }
}

# tehdn valinta kaikista operaatioista tietylle kyttjlle.

function select_paivystys_ids($kayttajat_id) {
  $koko = ota_yksi("SELECT COUNT(*)
                    FROM paivystys
                    WHERE id > 2");
  if ($koko > 5)
    $koko = 5;
  echo "<select multiple size=\"$koko\" name=\"paivystys_ids[]\">\n";

  $sql =
    "SELECT id, nimi
     FROM paivystys
     WHERE id > 2
     ORDER BY nimi";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($data = mysql_fetch_row($result)) {
      $option_value = $data[0];
      $option_label = $data[1];
      echo "<option value=\"$option_value\"";
      if (ota_yksi("SELECT COUNT(*)
                    FROM kayttajat_paivystys
                    WHERE kayttajat_id = $kayttajat_id
                          AND paivystys_id = $option_value"))
	echo " selected";
      echo ">$option_label\n";
    }
  }
  
  echo "</select>\n";
}

# nytetn taulukossa olevat paivystyset

function list_paivystys_ids($paivystys_ids) {
  foreach ($paivystys_ids as $id) {
    echo " " . tab_col_id("paivystys","nimi",$id);
  }
  echo "\n";
}

# tehdn paivystys_ids lista tietylle kyttjlle.
function fetch_paivystys_ids($id) {
  $ret = array();
  $sql = "SELECT paivystys_id FROM kayttajat_paivystys WHERE kayttajat_id = $id";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($d = mysql_fetch_row($result)) {
      $ret[] = $d[0];
    }
  }
  return $ret;
}

# asetetaan kyttjn paivystys_ids lista kantaan.
function set_paivystys_ids($now,$id,$paivystys_ids) {
  $now = date('Y-m-d H:i:s');
  $sql = "DELETE FROM kayttajat_paivystys WHERE kayttajat_id = $id;";
  my_mysql_query($sql);
  loki($sql);
  foreach ($paivystys_ids as $paivystys_id) {
    $sql =
      "INSERT INTO kayttajat_paivystys
       SET kayttajat_id = $id,
           paivystys_id = $paivystys_id,
           ts = '$now'";
      my_mysql_query($sql);
      loki($sql);
  }
}

echo "
<html>
<head>
 <title>VIHA - Kyttjt</title>
</head>
" . body_bgcolor() . "
<h1>Kyttoikeustietojen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$username = get_txt('username');
$root = get_nro_0('root');
$password = get_txt('password');
$hlo_id = get_nro_0('hlo_id');
$alue_ids = get_multi_nro('alue_ids');
$paivystys_ids = get_multi_nro('paivystys_ids');

$add = get_txt('add');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');
$clear = get_txt('clear');

oltava_0($file);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = kayttaja_add_ok($herja,$username,$root,$password,$hlo_id,$alue_ids,
			 $paivystys_ids);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $hash = crypt($password);
    $sql =
      "INSERT INTO $table
       SET username = '$username',
           root = $root,
           password = '$hash',
           hlo_id = $hlo_id,
           ts = '$now'";
    my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "ADD";
    $new_id = last_insert_id();
    loki("$sql id=$new_id");
    set_alue_ids($now,$new_id,$alue_ids);
    set_paivystys_ids($now,$new_id,$paivystys_ids);
  }
  p_herja($ret,$herja);
 }

if (($save != '') && saa_tehda("$file:save")) {
  $ret = kayttaja_save_ok($herja,$id,$username,$root,$password,$hlo_id,
			  $alue_ids,$paivystys_ids);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    if ($password !== '') {
      # since password is hashed, we touch it only if it was changed.
      $hash = crypt($password);
      $password_sql = "password = '$hash',";
    }
    $sql = "
UPDATE $table
SET username='$username',
    root = $root,
    $password_sql
    hlo_id = $hlo_id,
    ts='$now'
WHERE id=$id
";
    my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
    set_alue_ids($now,$id,$alue_ids);
    set_paivystys_ids($now,$id,$paivystys_ids);
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = kayttaja_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    my_mysql_query ($sql);
    loki($sql);
    $sql = "DELETE FROM kayttajat_paivystys WHERE kayttajat_id = $id";
    my_mysql_query ($sql);
    loki($sql);
    $sql = "DELETE FROM kayttajat_alue WHERE kayttajat_id = $id";
    my_mysql_query ($sql);
    loki($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $username = '';
    $root = "0";
    $password = "";
    $hlo_id = "0";
    $alue_ids = array();
    $paivystys_ids = array();
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = kayttaja_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $username = $a['username']; 
  $root = $a['root']; 
  $password = $a['password']; 
  $hlo_id = $a['hlo_id'];
  $alue_ids = fetch_alue_ids($id);
  $paivystys_ids = fetch_paivystys_ids($id);
}		  
echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Kyttjnimi:";
if ($readonly) {
  echo "<td>$username\n";
} else {
  echo "<td><input type=\"text\" name=\"username\" size=16 maxlength=16";
  echo " value=\"$username\"> username, login name\n";
}

echo "<tr><td>Pkyttj:";
if ($readonly) {
  echo "<td>" . tab_col_id("juuei","",$root) . "\n";
} else {
  echo "<td>";
  tee_valinta("root", $root, "juuei", "id", "juuei", "ORDER BY juuei");
}

echo "<tr><td>Salasana:";
if ($readonly) {
  echo "<td>\n";
} else {
  echo "<td><input type=\"text\" name=\"password\" size=16 maxlength=16";
  echo " value=\"\"> (voidaan vain asettaa uusi)\n";
}

echo "<tr><td>Henkil:";
if ($readonly) {
  echo "<td>" . tab_col_id_nobody("hlo","nimi",$hlo_id);
} else {
  echo "<td>\n";
  tee_valinta_plus_0("hlo_id", $hlo_id, "hlo", "id",
		     "nimi", "ORDER BY nimi", "EI KUKAAN");
}

echo "<tr><td>Alueet:";
if ($readonly) {
  echo "<td>\n";
  list_alue_ids($alue_ids);
 }  else {
  echo "<td>\n";
  select_alue_ids($id);
 }

echo "<tr><td>Operaatiot:";
if ($readonly) {
  echo "<td>\n";
  list_paivystys_ids($paivystys_ids);
 }  else {
  echo "<td>\n";
  select_paivystys_ids($id);
 }

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT $table.id, $table.ts, $table.username, $table.root, $table.hlo_id
FROM $table
ORDER BY id
";
$result = my_mysql_query($sql);
if ($result) {
    echo "<p><TABLE BORDER=1>\n";
    echo tr_bgcolor()
      . "<TH>Id<TH>Aikaleima<TH>Kyttjnimi<TH>Pkyttj"
      . "<TH>Alueet<TH>Operaatiot<TH>Henkil\n";
    while ($a = mysql_fetch_array($result)) {
      echo "<TR><TD>$a[id]",
	"<TD>$a[ts]",
	"<TD>$a[username]",
	"<TD>" . tab_col_id("juuei","",$a['root']),
	"<td>" . ota_yksi("SELECT COUNT(*)
                           FROM kayttajat_alue
                           WHERE kayttajat_id = $a[id]"),
	"<td>" . ota_yksi("SELECT COUNT(*)
                           FROM kayttajat_paivystys
                           WHERE kayttajat_id = $a[id]"),
	"<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']);
      if (($id == "0") && ($a['id'] != "1")) {
	echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
	echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
      }
    }
    echo "</TABLE>";
} else {
    echo "<P>Plop. Ei kyttoikeustietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: kayttajat.php,v 1.36 2009/05/04 05:17:31 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/kayttajat.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "kayttajat";
$file = basename(__FILE__);

include "common.php";
include "kayttaja-ok.php";

# tehdn valinta kaikista alueista tietylle kyttjlle.

function select_alue_ids($kayttajat_id) {
  $koko = ota_yksi("SELECT COUNT(*)
                    FROM alue
                    WHERE id > 2");
  if ($koko > 5)
    $koko = 5;
  echo "<select multiple size=\"$koko\" name=\"alue_ids[]\">\n";

  $sql =
    "SELECT id, alue
     FROM alue
     WHERE id > 2
     ORDER BY alue";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($data = mysql_fetch_row($result)) {
      $option_value = $data[0];
      $option_label = $data[1];
      echo "<option value=\"$option_value\"";
      if (ota_yksi("SELECT COUNT(*)
                    FROM kayttajat_alue
                    WHERE kayttajat_id = $kayttajat_id
                          AND alue_id = $option_value"))
	echo " selected";
      echo ">$option_label\n";
    }
  }
  
  echo "</select>\n";
}

# nytetn taulukossa olevat alueet

function list_alue_ids($alue_ids) {
  foreach ($alue_ids as $id) {
    echo " " . tab_col_id("alue","",$id);
  }
  echo "\n";
}

# tehdn alue_ids lista tietylle kyttjlle.
function fetch_alue_ids($id) {
  $ret = array();
  $sql = "SELECT alue_id FROM kayttajat_alue WHERE kayttajat_id = $id";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($d = mysql_fetch_row($result)) {
      $ret[] = $d[0];
    }
  }
  return $ret;
}

# asetetaan kyttjn alue_ids lista kantaan.
function set_alue_ids($now,$id,$alue_ids) {
  $now = date('Y-m-d H:i:s');
  $sql = "DELETE FROM kayttajat_alue WHERE kayttajat_id = $id;";
  my_mysql_query($sql);
  loki($sql);
  foreach ($alue_ids as $alue_id) {
    $sql =
      "INSERT INTO kayttajat_alue
       SET kayttajat_id = $id,
           alue_id = $alue_id,
           ts = '$now'";
      my_mysql_query($sql);
      loki($sql);
  }
}

# tehdn valinta kaikista operaatioista tietylle kyttjlle.

function select_paivystys_ids($kayttajat_id) {
  $koko = ota_yksi("SELECT COUNT(*)
                    FROM paivystys
                    WHERE id > 2");
  if ($koko > 5)
    $koko = 5;
  echo "<select multiple size=\"$koko\" name=\"paivystys_ids[]\">\n";

  $sql =
    "SELECT id, nimi
     FROM paivystys
     WHERE id > 2
     ORDER BY alkoi DESC, nimi ASC";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($data = mysql_fetch_row($result)) {
      $option_value = $data[0];
      $option_label = $data[1];
      echo "<option value=\"$option_value\"";
      if (ota_yksi("SELECT COUNT(*)
                    FROM kayttajat_paivystys
                    WHERE kayttajat_id = $kayttajat_id
                          AND paivystys_id = $option_value"))
	echo " selected";
      echo ">" . muotoile_operaatio($option_value) . "\n";
    }
  }
  
  echo "</select>\n";
}

# nytetn taulukossa olevat paivystyset

function list_paivystys_ids($paivystys_ids) {
  foreach ($paivystys_ids as $id) {
    echo " " . tab_col_id("paivystys","nimi",$id);
  }
  echo "\n";
}

# tehdn paivystys_ids lista tietylle kyttjlle.
function fetch_paivystys_ids($id) {
  $ret = array();
  $sql =
    "SELECT paivystys_id FROM kayttajat_paivystys WHERE kayttajat_id = $id";
  $result = my_mysql_query($sql);
  if ($result) {
    while ($d = mysql_fetch_row($result)) {
      $ret[] = $d[0];
    }
  }
  return $ret;
}

# asetetaan kyttjn paivystys_ids lista kantaan.
function set_paivystys_ids($now,$id,$paivystys_ids) {
  $now = date('Y-m-d H:i:s');
  $sql = "DELETE FROM kayttajat_paivystys WHERE kayttajat_id = $id;";
  my_mysql_query($sql);
  loki($sql);
  foreach ($paivystys_ids as $paivystys_id) {
    $sql =
      "INSERT INTO kayttajat_paivystys
       SET kayttajat_id = $id,
           paivystys_id = $paivystys_id,
           ts = '$now'";
      my_mysql_query($sql);
      loki($sql);
  }
}

echo "
<html>
<head>
 <title>VIHA - Kyttjt</title>
</head>
" . body_bgcolor() . "
<h1>Kyttoikeustietojen ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
if ($id === '')
  $id = post_nro_0('id');
$username = post_txt('username');
$root = post_nro_0('root');
$password = post_txt('password');
$hlo_id = post_nro_0('hlo_id');
$alue_ids = post_multi_nro('alue_ids');
$paivystys_ids = post_multi_nro('paivystys_ids');

$add = post_txt('add');
$save = post_txt('save');
$confirm = post_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');
$clear = post_txt('clear');

oltava_0($file);

if ($add != '') {
  $ret = kayttaja_add_ok($herja,$username,$root,$password,$hlo_id,$alue_ids,
			 $paivystys_ids);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $hash = crypt($password);
    $sql =
      "INSERT INTO $table
       SET username = '$username',
           root = $root,
           password = '$hash',
           hlo_id = $hlo_id,
           ts = '$now'";
    my_mysql_query ($sql);
    $new_id = last_insert_id();
    loki("$sql id=$new_id");
    set_alue_ids($now,$new_id,$alue_ids);
    set_paivystys_ids($now,$new_id,$paivystys_ids);
    tehty("Listty kyttj $username");
    $clear = "ADD";
  }
  p_herja($ret,$herja);
 }

if ($save != '') {
  $ret = kayttaja_save_ok($herja,$id,$username,$root,$password,$hlo_id,
			  $alue_ids,$paivystys_ids);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    if ($password !== '') {
      # since password is hashed, we touch it only if it was changed.
      $hash = crypt($password);
      $password_sql = "password = '$hash',";
    }
    $sql =
      "UPDATE $table
       SET username='$username',
           root = $root,
           $password_sql
           hlo_id = $hlo_id,
           ts='$now'
       WHERE id=$id";
    my_mysql_query ($sql,true,true);
    set_alue_ids($now,$id,$alue_ids);
    set_paivystys_ids($now,$id,$paivystys_ids);
    tehty("Pivitetty kyttj $username");
  }
  p_herja($ret,$herja);
 }

if ($confirm != '') {
  $ret = kayttaja_remove_ok($herja,$id);
  if ($ret != 2) {
    $tmp_nimi = tab_col_id("kayttajat","username",$id);
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    my_mysql_query ($sql,true,true);
    $sql = "DELETE FROM kayttajat_paivystys WHERE kayttajat_id = $id";
    my_mysql_query ($sql,true,true);
    $sql = "DELETE FROM kayttajat_alue WHERE kayttajat_id = $id";
    my_mysql_query ($sql,true,true);
    tehty("Poistettu kyttj $username");
    $clear = "CONFIRM";
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $username = '';
    $root = "0";
    $password = "";
    $hlo_id = "0";
    $alue_ids = array();
    $paivystys_ids = array();
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = kayttaja_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"POST\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $username = $a['username']; 
  $root = $a['root']; 
  $password = $a['password']; 
  $hlo_id = $a['hlo_id'];
  $alue_ids = fetch_alue_ids($id);
  $paivystys_ids = fetch_paivystys_ids($id);
}		  
echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Kyttjnimi:";
if ($readonly) {
  echo "<td>$username\n";
} else {
  echo "<td><input type=\"text\" name=\"username\" size=16 maxlength=16";
  echo " value=\"$username\"> username, login name\n";
}

echo "<tr><td>Pkyttj:";
if ($readonly) {
  echo "<td>" . tab_col_id("juuei","",$root) . "\n";
} else {
  echo "<td>";
  tee_valinta("root", $root, "juuei", "id", "juuei", "ORDER BY juuei");
}

echo "<tr><td>Salasana:";
if ($readonly) {
  echo "<td>\n";
} else {
  echo "<td><input type=\"text\" name=\"password\" size=16 maxlength=16";
  echo " value=\"\"> (voidaan vain asettaa uusi)\n";
}

echo "<tr><td>Henkil:";
if ($readonly) {
  echo "<td>" . tab_col_id_nobody("hlo","nimi",$hlo_id);
} else {
  echo "<td>\n";
  tee_valinta_plus_0("hlo_id", $hlo_id, "hlo", "id",
		     "nimi", "ORDER BY nimi", "EI KUKAAN");
}

echo "<tr><td>Alueet:";
if ($readonly) {
  echo "<td>\n";
  list_alue_ids($alue_ids);
 }  else {
  echo "<td>\n";
  select_alue_ids($id);
 }

echo "<tr><td>Operaatiot:";
if ($readonly) {
  echo "<td>\n";
  list_paivystys_ids($paivystys_ids);
 }  else {
  echo "<td>\n";
  select_paivystys_ids($id);
 }

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT $table.id, $table.ts, $table.username, $table.root, $table.hlo_id
FROM $table
ORDER BY username
";
$result = my_mysql_query($sql);
if ($result) {
    echo "<p><TABLE BORDER=1>\n";
    tr_reset();
    echo tr_vaalsin()
      . "<TH>Id<TH>Aikaleima<TH>Kyttjnimi<TH>Pkyttj"
      . "<TH>Alueet<TH>Operaatiot<TH>Henkil\n";
    while ($a = mysql_fetch_array($result)) {
      echo tr() . "<TD>$a[id]",
	"<TD>$a[ts]",
	"<TD>$a[username]",
	"<TD>" . tab_col_id("juuei","",$a['root']),
	"<td>" . ota_yksi("SELECT COUNT(*)
                           FROM kayttajat_alue
                           WHERE kayttajat_id = $a[id]"),
	"<td>" . ota_yksi("SELECT COUNT(*)
                           FROM kayttajat_paivystys
                           WHERE kayttajat_id = $a[id]"),
	"<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']);
      if (($id == "0") && ($a['id'] != "1")) {
	echo "<td><a href=\"$table.php?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
	echo "<td><a href=\"$table.php?id=$a[id]&remove=POISTA\">POISTA</a>\n";
      }
    }
    echo "</TABLE>";
} else {
    echo "<P>Plop. Ei kyttoikeustietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: kayttajat.php,v 1.39 2009/10/09 16:43:51 riku Exp $ -->
